==> jc-1.4.0.tar.gz: soot/jimple/ReachingTypeDumper.h <==
// public class soot.jimple.ReachingTypeDumper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 21ec07ccf4b2d8ef soot_jimple_ReachingTypeDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_ReachingTypeDumper_H_
#define _JC_soot_jimple_ReachingTypeDumper_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_soot_jimple_ReachingTypeDumper$sub_refs	_jc_soot_jimple_ReachingTypeDumper$sub_refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs	_jc_soot_jimple_ReachingTypeDumper$sub_nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$refs	_jc_soot_jimple_ReachingTypeDumper$refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$nonrefs	_jc_soot_jimple_ReachingTypeDumper$nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$object	_jc_soot_jimple_ReachingTypeDumper$object;

typedef const struct _jc_soot_jimple_ReachingTypeDumper$vmethods	_jc_soot_jimple_ReachingTypeDumper$vmethods;
typedef const struct _jc_soot_jimple_ReachingTypeDumper$vtable	_jc_soot_jimple_ReachingTypeDumper$vtable;
typedef const struct _jc_soot_jimple_ReachingTypeDumper$vtype	_jc_soot_jimple_ReachingTypeDumper$vtype;

// Constructors
extern void _jc_soot_jimple_ReachingTypeDumper$method$_init$9d963e7a7b97e976(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_jimple_ReachingTypeDumper$method$dump$1356784dfb24ffa0(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *);
extern void _jc_soot_jimple_ReachingTypeDumper$method$handleClass$378cc6a6c3405953(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_java_io_PrintWriter$object *, struct _jc_soot_SootClass$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_ReachingTypeDumper$method_info$dump$1356784dfb24ffa0;
extern _jc_method _jc_soot_jimple_ReachingTypeDumper$method_info$handleClass$378cc6a6c3405953;

// Virtual methods structure
struct _jc_soot_jimple_ReachingTypeDumper$vmethods {
	void	(*dump$1356784dfb24ffa0)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *);
	void	(*handleClass$378cc6a6c3405953)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_java_io_PrintWriter$object *, struct _jc_soot_SootClass$object *);
};

// Vtable
struct _jc_soot_jimple_ReachingTypeDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ReachingTypeDumper$vmethods	soot_jimple_ReachingTypeDumper;
};

// Vtype
struct _jc_soot_jimple_ReachingTypeDumper$vtype {
	_jc_type			type;
	_jc_soot_jimple_ReachingTypeDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper$sub_refs {
	struct _jc_object	*pa;
	struct _jc_java_lang_String$object	*output__5fdir;
};

// Reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper$refs {
    _jc_soot_jimple_ReachingTypeDumper$sub_refs	soot_jimple_ReachingTypeDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs	soot_jimple_ReachingTypeDumper;
};

// Object instance structure
struct _jc_soot_jimple_ReachingTypeDumper$object {
	_jc_soot_jimple_ReachingTypeDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_ReachingTypeDumper$vtype	*vtype;
	_jc_soot_jimple_ReachingTypeDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_ReachingTypeDumper$vtype _jc_soot_jimple_ReachingTypeDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_ReachingTypeDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_ReachingTypeDumper$class_object;

#endif	/* _JC_soot_jimple_ReachingTypeDumper_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/ReachingTypeDumper.h <==
// public class soot.jimple.ReachingTypeDumper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 21ec07ccf4b2d8ef soot_jimple_ReachingTypeDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_ReachingTypeDumper_H_
#define _JC_soot_jimple_ReachingTypeDumper_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_soot_jimple_ReachingTypeDumper$sub_refs	_jc_soot_jimple_ReachingTypeDumper$sub_refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs	_jc_soot_jimple_ReachingTypeDumper$sub_nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$refs	_jc_soot_jimple_ReachingTypeDumper$refs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$nonrefs	_jc_soot_jimple_ReachingTypeDumper$nonrefs;
typedef struct _jc_soot_jimple_ReachingTypeDumper$object	_jc_soot_jimple_ReachingTypeDumper$object;

typedef const struct _jc_soot_jimple_ReachingTypeDumper$vmethods	_jc_soot_jimple_ReachingTypeDumper$vmethods;
typedef const struct _jc_soot_jimple_ReachingTypeDumper$vtable	_jc_soot_jimple_ReachingTypeDumper$vtable;
typedef const struct _jc_soot_jimple_ReachingTypeDumper$vtype	_jc_soot_jimple_ReachingTypeDumper$vtype;

// Constructors
extern void _jc_soot_jimple_ReachingTypeDumper$method$_init$9d963e7a7b97e976(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_ReachingTypeDumper$method$dump$1356784dfb24ffa0(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_ReachingTypeDumper$method$handleClass$378cc6a6c3405953(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_java_io_PrintWriter$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_ReachingTypeDumper$method_info$dump$1356784dfb24ffa0;
extern _jc_method _jc_soot_jimple_ReachingTypeDumper$method_info$handleClass$378cc6a6c3405953;

// Virtual methods structure
struct _jc_soot_jimple_ReachingTypeDumper$vmethods {
	void	(*dump$1356784dfb24ffa0)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *) _JC_JCNI_ATTR;
	void	(*handleClass$378cc6a6c3405953)(_jc_env *, struct _jc_soot_jimple_ReachingTypeDumper$object *, struct _jc_java_io_PrintWriter$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_ReachingTypeDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ReachingTypeDumper$vmethods	soot_jimple_ReachingTypeDumper;
};

// Vtype
struct _jc_soot_jimple_ReachingTypeDumper$vtype {
	_jc_type			type;
	_jc_soot_jimple_ReachingTypeDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper$sub_refs {
	struct _jc_object	*pa;
	struct _jc_java_lang_String$object	*output__5fdir;
};

// Reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper$refs {
    _jc_soot_jimple_ReachingTypeDumper$sub_refs	soot_jimple_ReachingTypeDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_ReachingTypeDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ReachingTypeDumper$sub_nonrefs	soot_jimple_ReachingTypeDumper;
};

// Object instance structure
struct _jc_soot_jimple_ReachingTypeDumper$object {
	_jc_soot_jimple_ReachingTypeDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_ReachingTypeDumper$vtype	*vtype;
	_jc_soot_jimple_ReachingTypeDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_ReachingTypeDumper$vtype _jc_soot_jimple_ReachingTypeDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_ReachingTypeDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_ReachingTypeDumper$class_object;

#endif	/* _JC_soot_jimple_ReachingTypeDumper_H_ */
